@@ -16,6 +16,11 @@ email                : cniehaus@kde.org
 #include <kxmlguiwindow.h>
 #include "periodictableview.h"
 #include "unitsettingsdialog.h"
+#include "isotopetabledialog.h"
+#include "elementdataviewer.h"
+#include "tablesdialog.h"
+#include "rsdialog.h"
+#include "calculator/calculator.h"
 
 class KTabWidget;
 class KAction;
@@ -25,17 +30,15 @@ class QVBoxLayout;
 class QDockWidget;
 class DetailedInfoDlg;
 class PeriodicTableView;
-class MolcalcWidget;
 class DetailedGraphicalOverview;
 class GradientWidgetImpl;
 class GlossaryDialog;
 class IsotopeTable;
-class SearchWidget;
 class QKeyEvent;
 class LegendWidget;
 class TableInfoWidget;
 class ExportDialog;
-class DetailedQmlView;
+class MoleculeDialog;
 
 /**
  * @brief Application Main Window
@@ -58,6 +61,8 @@ public:
      * Default Destructor
      */
     virtual ~Kalzium();
+    
+    void loadMolecule(const QString &moleculeFile);
 
 private:
     DetailedInfoDlg   *m_infoDialog;
@@ -68,6 +73,16 @@ private:
 
     PeriodicTableView *m_periodicTable;
 
+    IsotopeTableDialog *m_isotopeDialog;
+
+    ElementDataViewer *m_elementDataPlotter;
+
+    TablesDialog *m_tablesDialog;
+
+    RSDialog *m_rsDialog;
+
+    calculator *m_calculator;
+
     /**
      *initialize actions
      */
@@ -105,8 +120,6 @@ private:
 
     QAction *m_legendAction;
 
-    MolcalcWidget *m_calcWidget;
-
     GradientWidgetImpl *m_gradientWidget;
 
     DetailedGraphicalOverview *m_detailWidget;
@@ -124,8 +137,6 @@ private:
 
     GlossaryDialog *m_glossarydlg;
 
-    SearchWidget *m_searchWidget;
-
     ExportDialog *m_exportDialog;
 
     UnitSettingsDialog *m_unitsDialog;
@@ -157,7 +168,7 @@ private slots:
      */
     void slotRS();
 
-    void slotMoleculeviewer();
+    MoleculeDialog *slotMoleculeviewer();
 
     void slotOBConverter();
 
