@@ -17,7 +17,7 @@
 
 
 #include "kalziumunitcombobox.h"
-#include <kunitconversion/converter.h>
+#include "kalziumutils.h"
 
 KalziumUnitCombobox::KalziumUnitCombobox(QWidget* parent): QComboBox(parent)
 {
@@ -32,17 +32,7 @@ KalziumUnitCombobox::KalziumUnitCombobox( const QList< int > &unitList, QWidget*
 
 void KalziumUnitCombobox::setUnitList(const QList< int >& unitList)
 {
-    QString unitString;
-
-    clear();
-
-    foreach( int unit, unitList) {
-        unitString = KUnitConversion::Converter().unit(unit).data()->description();
-        unitString.append(" (");
-        unitString.append(KUnitConversion::Converter().unit(unit).data()->symbol());
-        unitString.append(")");
-        addItem( unitString, unit );
-    }
+    KalziumUtils::populateUnitCombobox( this, unitList ) ;
 }
 
 int KalziumUnitCombobox::getCurrentUnitId() const
